Crate rspack_location

Crate rspack_location 

Structs

ArchivedRealDependencyLocation
An archived RealDependencyLocation
ArchivedSourcePosition
An archived SourcePosition
ArchivedSyntheticDependencyLocation
An archived SyntheticDependencyLocation
Buffer
A correctly sized stack allocation for the formatted integer to be written into.
RealDependencyLocation
Represents the real location of a dependency in a source file, including both start and optional end positions. These positions are described in terms of lines and columns in the source code.
RealDependencyLocationResolver
The resolver for an archived RealDependencyLocation
SourcePosition
Represents a position within a source file (line and column). Semantics match V8 Error stack positions:
SourcePositionResolver
The resolver for an archived SourcePosition
SyntheticDependencyLocation
Represents a synthetic dependency location, such as a generated dependency.
SyntheticDependencyLocationResolver
The resolver for an archived SyntheticDependencyLocation

Enums

ArchivedDependencyLocation
An archived DependencyLocation
DependencyLocation
Real source locations sort before synthetic locations. Real locations are ordered by their start position and then their optional end position.
DependencyLocationResolver
The resolver for an archived DependencyLocation